/*
 * Copyright 2009 OW2 Chameleon
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ow2.chameleon.core;

import java.io.File;

import org.osgi.framework.Bundle;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;

/**
 * The Debug Activator launches ShellTUI if enabled.
 * @author <a href="mailto:chameleon-dev@ow2.org">Chameleon Project Team</a>
 */
public class DebugActivator implements BundleActivator {

    /**
     * Shell Tui prefix.
     */
    public static final String SHELL_TUI = "org.apache.felix.shell.tui-";

    /**
     * The core directory.
     */
    private File directory;

    /**
     * Initializes the activator.
     * @param dir the core directory.
     */
    public DebugActivator(File dir) {
        directory = dir;
    }

    /**
     * Starts and Installs the Shell TUI.
     * @param bc the bundle context
     * @throws Exception if the shell tui cannot be installed correctly.
     * @see org.osgi.framework.BundleActivator#
     *  start(org.osgi.framework.BundleContext)
     */
    public void start(BundleContext bc) throws Exception {
        File[] files = directory.listFiles();
        for (int i = 0; i < files.length; i++) {
            if (StringUtils.contains(files[i].getName(), SHELL_TUI)) {
                Bundle bundle = bc.installBundle(files[i].toURI().toURL().toExternalForm());
                bundle.start();
                return;
            }
        }

        throw new Exception("The Shell-TUI bundle cannot be installed");

    }

    /**
     * Does nothing.
     * @param bc the bundle context
     * @throws Exception cannot be raised.
     * @see org.osgi.framework.BundleActivator#
     *  stop(org.osgi.framework.BundleContext)
     */
    public void stop(BundleContext bc) throws Exception {
        // Nothing to do.
    }

}
